@@ -1,40 +1,55 @@
 local files     = require 'files'
 local lang      = require 'language'
 local util      = require 'utility'
-local sp        = require 'bee.subprocess'
 local guide     = require "parser.guide"
 local converter = require 'proto.converter'
+local autoreq   = require 'core.completion.auto-require'
+local rpath     = require 'workspace.require-path'
+local furi      = require 'file-uri'
+local vm        = require 'vm'
 
+---@param uri  uri
+---@param row  integer
+---@param mode string
+---@param code string
 local function checkDisableByLuaDocExits(uri, row, mode, code)
     if row < 0 then
         return nil
     end
     local state = files.getState(uri)
+    if not state then
+        return nil
+    end
     local lines = state.lines
     if state.ast.docs and lines then
-        return guide.eachSourceBetween(state.ast.docs, guide.positionOf(row, 0), guide.positionOf(row + 1, 0), function (doc)
-            if  doc.type == 'doc.diagnostic'
-            and doc.mode == mode then
-                if doc.names then
-                    return {
-                        start   = doc.finish,
-                        finish  = doc.finish,
-                        newText = ', ' .. code,
-                    }
-                else
-                    return {
-                        start   = doc.finish,
-                        finish  = doc.finish,
-                        newText = ': ' .. code,
-                    }
+        return guide.eachSourceBetween(
+            state.ast.docs,
+            guide.positionOf(row, 0),
+            guide.positionOf(row + 1, 0),
+            function (doc)
+                if  doc.type == 'doc.diagnostic'
+                and doc.mode == mode then
+                    if doc.names then
+                        return {
+                            start   = doc.finish,
+                            finish  = doc.finish,
+                            newText = ', ' .. code,
+                        }
+                    else
+                        return {
+                            start   = doc.finish,
+                            finish  = doc.finish,
+                            newText = ': ' .. code,
+                        }
+                    end
                 end
             end
-        end)
+        )
     end
     return nil
 end
 
-local function checkDisableByLuaDocInsert(uri, row, mode, code)
+local function checkDisableByLuaDocInsert(_uri, row, mode, code)
     return {
         start   = guide.positionOf(row, 0),
         finish  = guide.positionOf(row, 0),
@@ -43,13 +58,13 @@ local function checkDisableByLuaDocInsert(uri, row, mode, code)
 end
 
 local function disableDiagnostic(uri, code, start, results)
-    local row   = guide.rowColOf(start)
+    local row = guide.rowColOf(start)
     results[#results+1] = {
         title   = lang.script('ACTION_DISABLE_DIAG', code),
         kind    = 'quickfix',
         command = {
-            title    = lang.script.COMMAND_DISABLE_DIAG,
-            command = 'lua.setConfig',
+            title     = lang.script.COMMAND_DISABLE_DIAG,
+            command   = 'lua.setConfig',
             arguments = {
                 {
                     key    = 'Lua.diagnostics.disable',
@@ -86,7 +101,7 @@ local function markGlobal(uri, name, results)
         kind    = 'quickfix',
         command = {
             title     = lang.script.COMMAND_MARK_GLOBAL,
-            command = 'lua.setConfig',
+            command   = 'lua.setConfig',
             arguments = {
                 {
                     key    = 'Lua.diagnostics.globals',
@@ -119,9 +134,12 @@ local function changeVersion(uri, version, results)
 end
 
 local function solveUndefinedGlobal(uri, diag, results)
-    local ast    = files.getState(uri)
-    local start  = converter.unpackRange(uri, diag.range)
-    guide.eachSourceContain(ast.ast, start, function (source)
+    local state = files.getState(uri)
+    if not state then
+        return
+    end
+    local start = converter.unpackRange(state, diag.range)
+    guide.eachSourceContain(state.ast, start, function (source)
         if source.type ~= 'getglobal' then
             return
         end
@@ -138,9 +156,12 @@ local function solveUndefinedGlobal(uri, diag, results)
 end
 
 local function solveLowercaseGlobal(uri, diag, results)
-    local ast    = files.getState(uri)
-    local start  = converter.unpackRange(uri, diag.range)
-    guide.eachSourceContain(ast.ast, start, function (source)
+    local state = files.getState(uri)
+    if not state then
+        return
+    end
+    local start = converter.unpackRange(state, diag.range)
+    guide.eachSourceContain(state.ast, start, function (source)
         if source.type ~= 'setglobal' then
             return
         end
@@ -151,10 +172,13 @@ local function solveLowercaseGlobal(uri, diag, results)
 end
 
 local function findSyntax(uri, diag)
-    local ast = files.getState(uri)
-    for _, err in ipairs(ast.errs) do
+    local state = files.getState(uri)
+    if not state then
+        return
+    end
+    for _, err in ipairs(state.errs) do
         if err.type:lower():gsub('_', '-') == diag.code then
-            local range = converter.packRange(uri, err.start, err.finish)
+            local range = converter.packRange(state, err.start, err.finish)
             if util.equal(range, diag.range) then
                 return err
             end
@@ -174,7 +198,6 @@ local function solveSyntaxByChangeVersion(uri, err, results)
 end
 
 local function solveSyntaxByAddDoEnd(uri, err, results)
-    local text   = files.getText(uri)
     results[#results+1] = {
         title = lang.script.ACTION_ADD_DO_END,
         kind = 'quickfix',
@@ -209,7 +232,7 @@ local function solveSyntaxByFix(uri, err, results)
     results[#results+1] = {
         title = lang.script('ACTION_' .. err.fix.title, err.fix),
         kind  = 'quickfix',
-        edit = {
+        edit  = {
             changes = {
                 [uri] = changes,
             }
@@ -217,7 +240,7 @@ local function solveSyntaxByFix(uri, err, results)
     }
 end
 
-local function solveSyntaxUnicodeName(uri, err, results)
+local function solveSyntaxUnicodeName(uri, _err, results)
     results[#results+1] = {
         title   = lang.script('ACTION_RUNTIME_UNICODE_NAME'),
         kind    = 'quickfix',
@@ -256,7 +279,11 @@ local function solveSyntax(uri, diag, results)
 end
 
 local function solveNewlineCall(uri, diag, results)
-    local start = converter.unpackRange(uri, diag.range)
+    local state = files.getState(uri)
+    if not state then
+        return
+    end
+    local start = converter.unpackRange(state, diag.range)
     results[#results+1] = {
         title = lang.script.ACTION_ADD_SEMICOLON,
         kind = 'quickfix',
@@ -264,8 +291,8 @@ local function solveNewlineCall(uri, diag, results)
             changes = {
                 [uri] = {
                     {
-                        start  = start,
-                        finish = start,
+                        start   = start,
+                        finish  = start,
                         newText = ';',
                     }
                 }
@@ -292,7 +319,7 @@ local function solveAmbiguity1(uri, diag, results)
     }
 end
 
-local function solveTrailingSpace(uri, diag, results)
+local function solveTrailingSpace(uri, _diag, results)
     results[#results+1] = {
         title = lang.script.ACTION_REMOVE_SPACE,
         kind = 'quickfix',
@@ -313,7 +340,7 @@ local function solveAwaitInSync(uri, diag, results)
     if not state then
         return
     end
-    local start, finish = converter.unpackRange(uri, diag.range)
+    local start, finish = converter.unpackRange(state, diag.range)
     local parentFunction
     guide.eachSourceType(state.ast, 'function', function (source)
         if source.start > finish
@@ -329,6 +356,8 @@ local function solveAwaitInSync(uri, diag, results)
     end
     local row = guide.rowColOf(parentFunction.start)
     local pos = guide.positionOf(row, 0)
+    local offset = guide.positionToOffset(state, pos + 1)
+    local space = state.lua:match('[ \t]*', offset)
     results[#results+1] = {
         title = lang.script.ACTION_MARK_ASYNC,
         kind = 'quickfix',
@@ -336,9 +365,9 @@ local function solveAwaitInSync(uri, diag, results)
             changes = {
                 [uri] = {
                     {
-                        start  = pos,
-                        finish = pos,
-                        newText = '---@async\n',
+                        start   = pos,
+                        finish  = pos,
+                        newText = space .. '---@async\n',
                     }
                 }
             }
@@ -346,6 +375,55 @@ local function solveAwaitInSync(uri, diag, results)
     }
 end
 
+local function solveSpell(uri, diag, results)
+    local state = files.getState(uri)
+    if not state then
+        return
+    end
+    local spell = require 'provider.spell'
+    local word = diag.data
+    if word == nil then
+        return
+    end
+
+    results[#results+1] = {
+        title   = lang.script('ACTION_ADD_DICT', word),
+        kind    = 'quickfix',
+        command = {
+            title     = lang.script.COMMAND_ADD_DICT,
+            command   = 'lua.setConfig',
+            arguments = {
+                {
+                    key    = 'Lua.spell.dict',
+                    action = 'add',
+                    value  = word,
+                    uri    = uri,
+                }
+            }
+        }
+    }
+
+    local suggests = spell.getSpellSuggest(word)
+    for _, suggest in ipairs(suggests) do
+        results[#results+1] = {
+            title = suggest,
+            kind = 'quickfix',
+            edit = {
+                changes = {
+                    [uri] = {
+                        {
+                            start   = converter.unpackPosition(state, diag.range.start),
+                            finish  = converter.unpackPosition(state, diag.range["end"]),
+                            newText = suggest
+                        }
+                    }
+                }
+            }
+        }
+    end
+
+end
+
 local function solveDiagnostic(uri, diag, start, results)
     if diag.source == lang.script.DIAG_SYNTAX_CHECK then
         solveSyntax(uri, diag, results)
@@ -366,6 +444,8 @@ local function solveDiagnostic(uri, diag, start, results)
         solveTrailingSpace(uri, diag, results)
     elseif diag.code == 'await-in-sync' then
         solveAwaitInSync(uri, diag, results)
+    elseif diag.code == 'spell-check' then
+        solveSpell(uri, diag, results)
     end
     disableDiagnostic(uri, diag.code, start, results)
 end
@@ -382,7 +462,7 @@ end
 local function checkSwapParams(results, uri, start, finish)
     local state = files.getState(uri)
     local text  = files.getText(uri)
-    if not state then
+    if not state or not text then
         return
     end
     local args = {}
@@ -410,7 +490,13 @@ local function checkSwapParams(results, uri, start, finish)
                 )
             elseif source.type == 'funcargs' then
                 local var = source.parent.parent
-                if guide.isSet(var) then
+                if guide.isAssign(var) then
+                    if var.type == 'tablefield' then
+                        var = var.field
+                    end
+                    if var.type == 'tableindex' then
+                        var = var.index
+                    end
                     node = text:sub(
                         guide.positionToOffset(state, var.start) + 1,
                         guide.positionToOffset(state, var.finish)
@@ -542,28 +628,39 @@ end
 --end
 
 local function checkJsonToLua(results, uri, start, finish)
-    local text  = files.getText(uri)
-    local state = files.getState(uri)
+    local text         = files.getText(uri)
+    local state        = files.getState(uri)
+    if not state or not text then
+        return
+    end
     local startOffset  = guide.positionToOffset(state, start)
     local finishOffset = guide.positionToOffset(state, finish)
-    local jsonStart = text:match ('()[%{%[]', startOffset + 1)
+    local jsonStart = text:match('()["%{%[]', startOffset + 1)
     if not jsonStart then
         return
     end
-    local jsonFinish
+    local jsonFinish, finishChar
     for i = math.min(finishOffset, #text), jsonStart + 1, -1 do
         local char = text:sub(i, i)
         if char == ']'
         or char == '}' then
             jsonFinish = i
+            finishChar = char
             break
         end
     end
     if not jsonFinish then
         return
     end
-    if not text:sub(jsonStart, jsonFinish):find '"%s*%:' then
-        return
+    if finishChar == '}' then
+        if not text:sub(jsonStart, jsonFinish):find '"%s*%:' then
+            return
+        end
+    end
+    if finishChar == ']' then
+        if not text:sub(jsonStart, jsonFinish):find ',' then
+            return
+        end
     end
     results[#results+1] = {
         title = lang.script.ACTION_JSON_TO_LUA,
@@ -582,6 +679,54 @@ local function checkJsonToLua(results, uri, start, finish)
     }
 end
 
+local function findRequireTargets(visiblePaths)
+    local targets = {}
+    for _, visible in ipairs(visiblePaths) do
+        targets[#targets+1] = visible.name
+    end
+    return targets
+end
+
+local function checkMissingRequire(results, uri, start, finish)
+    local state = files.getState(uri)
+    local text  = files.getText(uri)
+    if not state or not text then
+        return
+    end
+
+    local function addRequires(global, endpos)
+        autoreq.check(state, global, endpos, function(moduleFile, _stemname, _targetSource)
+            local visiblePaths = rpath.getVisiblePath(uri, furi.decode(moduleFile))
+            if not visiblePaths or #visiblePaths == 0 then return end
+
+            for _, target in ipairs(findRequireTargets(visiblePaths)) do
+                results[#results+1] = {
+                    title = lang.script('ACTION_AUTOREQUIRE', target, global),
+                    kind = 'refactor.rewrite',
+                    command = {
+                        title     = 'autoRequire',
+                        command   = 'lua.autoRequire',
+                        arguments = {
+                            {
+                                uri         = guide.getUri(state.ast),
+                                target      = moduleFile,
+                                name        = global,
+                                requireName = target
+                            },
+                        },
+                    }
+                }
+            end
+        end)
+    end
+
+    guide.eachSourceBetween(state.ast, start, finish, function (source)
+        if vm.isUndefinedGlobal(source) then
+            addRequires(source[1], source.finish)
+        end
+    end)
+end
+
 return function (uri, start, finish, diagnostics)
     local ast = files.getState(uri)
     if not ast then
@@ -594,6 +739,7 @@ return function (uri, start, finish, diagnostics)
     checkSwapParams(results, uri, start, finish)
     --checkExtractAsFunction(results, uri, start, finish)
     checkJsonToLua(results, uri, start, finish)
+    checkMissingRequire(results, uri, start, finish)
 
     return results
 end
